# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.jsonable_encoder import jsonable_encoder
from ...core.request_options import RequestOptions
from ...core.unchecked_base_model import construct_type
from ...types.azure_blob_export_storage import AzureBlobExportStorage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawAzureClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        project: int,
        ordering: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.List[AzureBlobExportStorage]]:
        """
        Get a list of all Azure export storage connections.

        Parameters
        ----------
        project : int
            Project ID

        ordering : typing.Optional[str]
            Which field to use when ordering the results.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[AzureBlobExportStorage]]

        """
        _response = self._client_wrapper.httpx_client.request(
            "api/storages/export/azure",
            method="GET",
            params={
                "ordering": ordering,
                "project": project,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[AzureBlobExportStorage],
                    construct_type(
                        type_=typing.List[AzureBlobExportStorage],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        *,
        account_key: typing.Optional[str] = OMIT,
        account_name: typing.Optional[str] = OMIT,
        can_delete_objects: typing.Optional[bool] = OMIT,
        container: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        prefix: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        title: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[AzureBlobExportStorage]:
        """
        Create a new Azure export storage connection to store annotations.

        Parameters
        ----------
        account_key : typing.Optional[str]
            Azure Blob account key

        account_name : typing.Optional[str]
            Azure Blob account name

        can_delete_objects : typing.Optional[bool]
            Deletion from storage enabled

        container : typing.Optional[str]
            Azure blob container

        description : typing.Optional[str]
            Storage description

        prefix : typing.Optional[str]
            Azure blob prefix name

        project : typing.Optional[int]
            Project ID

        title : typing.Optional[str]
            Storage title

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[AzureBlobExportStorage]

        """
        _response = self._client_wrapper.httpx_client.request(
            "api/storages/export/azure",
            method="POST",
            json={
                "account_key": account_key,
                "account_name": account_name,
                "can_delete_objects": can_delete_objects,
                "container": container,
                "description": description,
                "prefix": prefix,
                "project": project,
                "title": title,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureBlobExportStorage,
                    construct_type(
                        type_=AzureBlobExportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def validate(
        self,
        *,
        account_key: typing.Optional[str] = OMIT,
        account_name: typing.Optional[str] = OMIT,
        can_delete_objects: typing.Optional[bool] = OMIT,
        container: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        id: typing.Optional[int] = OMIT,
        prefix: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        title: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[None]:
        """
        Validate a specific Azure export storage connection.

        Parameters
        ----------
        account_key : typing.Optional[str]
            Azure Blob account key

        account_name : typing.Optional[str]
            Azure Blob account name

        can_delete_objects : typing.Optional[bool]
            Deletion from storage enabled

        container : typing.Optional[str]
            Azure blob container

        description : typing.Optional[str]
            Storage description

        id : typing.Optional[int]
            Storage ID. If set, storage with specified ID will be updated

        prefix : typing.Optional[str]
            Azure blob prefix name

        project : typing.Optional[int]
            Project ID

        title : typing.Optional[str]
            Storage title

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/storages/export/azure/validate",
            method="POST",
            json={
                "account_key": account_key,
                "account_name": account_name,
                "can_delete_objects": can_delete_objects,
                "container": container,
                "description": description,
                "id": id,
                "prefix": prefix,
                "project": project,
                "title": title,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[AzureBlobExportStorage]:
        """
        Get a specific Azure export storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[AzureBlobExportStorage]

        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/storages/export/azure/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureBlobExportStorage,
                    construct_type(
                        type_=AzureBlobExportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[None]:
        """
        Delete a specific Azure export storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/storages/export/azure/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        id: int,
        *,
        account_key: typing.Optional[str] = OMIT,
        account_name: typing.Optional[str] = OMIT,
        can_delete_objects: typing.Optional[bool] = OMIT,
        container: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        prefix: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        title: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[AzureBlobExportStorage]:
        """
        Update a specific Azure export storage connection.

        Parameters
        ----------
        id : int

        account_key : typing.Optional[str]
            Azure Blob account key

        account_name : typing.Optional[str]
            Azure Blob account name

        can_delete_objects : typing.Optional[bool]
            Deletion from storage enabled

        container : typing.Optional[str]
            Azure blob container

        description : typing.Optional[str]
            Storage description

        prefix : typing.Optional[str]
            Azure blob prefix name

        project : typing.Optional[int]
            Project ID

        title : typing.Optional[str]
            Storage title

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[AzureBlobExportStorage]

        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/storages/export/azure/{jsonable_encoder(id)}",
            method="PATCH",
            json={
                "account_key": account_key,
                "account_name": account_name,
                "can_delete_objects": can_delete_objects,
                "container": container,
                "description": description,
                "prefix": prefix,
                "project": project,
                "title": title,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureBlobExportStorage,
                    construct_type(
                        type_=AzureBlobExportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def sync(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[AzureBlobExportStorage]:
        """
        Sync tasks from an Azure export storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[AzureBlobExportStorage]

        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/storages/export/azure/{jsonable_encoder(id)}/sync",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureBlobExportStorage,
                    construct_type(
                        type_=AzureBlobExportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawAzureClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        project: int,
        ordering: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.List[AzureBlobExportStorage]]:
        """
        Get a list of all Azure export storage connections.

        Parameters
        ----------
        project : int
            Project ID

        ordering : typing.Optional[str]
            Which field to use when ordering the results.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[AzureBlobExportStorage]]

        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/storages/export/azure",
            method="GET",
            params={
                "ordering": ordering,
                "project": project,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[AzureBlobExportStorage],
                    construct_type(
                        type_=typing.List[AzureBlobExportStorage],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        *,
        account_key: typing.Optional[str] = OMIT,
        account_name: typing.Optional[str] = OMIT,
        can_delete_objects: typing.Optional[bool] = OMIT,
        container: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        prefix: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        title: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[AzureBlobExportStorage]:
        """
        Create a new Azure export storage connection to store annotations.

        Parameters
        ----------
        account_key : typing.Optional[str]
            Azure Blob account key

        account_name : typing.Optional[str]
            Azure Blob account name

        can_delete_objects : typing.Optional[bool]
            Deletion from storage enabled

        container : typing.Optional[str]
            Azure blob container

        description : typing.Optional[str]
            Storage description

        prefix : typing.Optional[str]
            Azure blob prefix name

        project : typing.Optional[int]
            Project ID

        title : typing.Optional[str]
            Storage title

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[AzureBlobExportStorage]

        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/storages/export/azure",
            method="POST",
            json={
                "account_key": account_key,
                "account_name": account_name,
                "can_delete_objects": can_delete_objects,
                "container": container,
                "description": description,
                "prefix": prefix,
                "project": project,
                "title": title,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureBlobExportStorage,
                    construct_type(
                        type_=AzureBlobExportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def validate(
        self,
        *,
        account_key: typing.Optional[str] = OMIT,
        account_name: typing.Optional[str] = OMIT,
        can_delete_objects: typing.Optional[bool] = OMIT,
        container: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        id: typing.Optional[int] = OMIT,
        prefix: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        title: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[None]:
        """
        Validate a specific Azure export storage connection.

        Parameters
        ----------
        account_key : typing.Optional[str]
            Azure Blob account key

        account_name : typing.Optional[str]
            Azure Blob account name

        can_delete_objects : typing.Optional[bool]
            Deletion from storage enabled

        container : typing.Optional[str]
            Azure blob container

        description : typing.Optional[str]
            Storage description

        id : typing.Optional[int]
            Storage ID. If set, storage with specified ID will be updated

        prefix : typing.Optional[str]
            Azure blob prefix name

        project : typing.Optional[int]
            Project ID

        title : typing.Optional[str]
            Storage title

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/storages/export/azure/validate",
            method="POST",
            json={
                "account_key": account_key,
                "account_name": account_name,
                "can_delete_objects": can_delete_objects,
                "container": container,
                "description": description,
                "id": id,
                "prefix": prefix,
                "project": project,
                "title": title,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[AzureBlobExportStorage]:
        """
        Get a specific Azure export storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[AzureBlobExportStorage]

        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/storages/export/azure/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureBlobExportStorage,
                    construct_type(
                        type_=AzureBlobExportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[None]:
        """
        Delete a specific Azure export storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/storages/export/azure/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        id: int,
        *,
        account_key: typing.Optional[str] = OMIT,
        account_name: typing.Optional[str] = OMIT,
        can_delete_objects: typing.Optional[bool] = OMIT,
        container: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        prefix: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        title: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[AzureBlobExportStorage]:
        """
        Update a specific Azure export storage connection.

        Parameters
        ----------
        id : int

        account_key : typing.Optional[str]
            Azure Blob account key

        account_name : typing.Optional[str]
            Azure Blob account name

        can_delete_objects : typing.Optional[bool]
            Deletion from storage enabled

        container : typing.Optional[str]
            Azure blob container

        description : typing.Optional[str]
            Storage description

        prefix : typing.Optional[str]
            Azure blob prefix name

        project : typing.Optional[int]
            Project ID

        title : typing.Optional[str]
            Storage title

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[AzureBlobExportStorage]

        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/storages/export/azure/{jsonable_encoder(id)}",
            method="PATCH",
            json={
                "account_key": account_key,
                "account_name": account_name,
                "can_delete_objects": can_delete_objects,
                "container": container,
                "description": description,
                "prefix": prefix,
                "project": project,
                "title": title,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureBlobExportStorage,
                    construct_type(
                        type_=AzureBlobExportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def sync(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[AzureBlobExportStorage]:
        """
        Sync tasks from an Azure export storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[AzureBlobExportStorage]

        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/storages/export/azure/{jsonable_encoder(id)}/sync",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureBlobExportStorage,
                    construct_type(
                        type_=AzureBlobExportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
